% Auto-generated chapter 35 for nasai
% Hadiths in this chapter: 96

\hadithdefcmd{nasai}{3761}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ الرُّهَاوِيُّ، وَمُوسَى بْنُ عَبْدِ الرَّحْمَنِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَتْ يَمِينٌ يَحْلِفُ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ وَمُقَلِّبِ الْقُلُوبِ ‏"‏ ‏.‏\hadithno{3761}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Umar said:"The oath by which the Messenger of Allah used to swear was: 'No, by the Controller of the hearts}}
\hadithdefcmd{nasai}{3762}{أَخْبَرَنِي مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ الصَّلْتِ أَبُو يَعْلَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، عَنْ عَبَّادِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ كَانَتْ يَمِينُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي يَحْلِفُ بِهَا ‏ "‏ لاَ وَمُصَرِّفِ الْقُلُوبِ ‏"‏ ‏.‏\hadithno{3762}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salim that his father said:"The oath by which the Messenger of Allah used to swear was: 'No, by the Controller of the hearts}}
\hadithdefcmd{nasai}{3763}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَمَّا خَلَقَ اللَّهُ الْجَنَّةَ وَالنَّارَ أَرْسَلَ جِبْرِيلَ عَلَيْهِ السَّلاَمُ إِلَى الْجَنَّةِ فَقَالَ انْظُرْ إِلَيْهَا وَإِلَى مَا أَعْدَدْتُ لأَهْلِهَا فِيهَا ‏.‏ فَنَظَرَ إِلَيْهَا فَرَجَعَ فَقَالَ وَعِزَّتِكَ لاَ يَسْمَعُ بِهَا أَحَدٌ إِلاَّ دَخَلَهَا ‏.‏ فَأَمَرَ بِهَا فَحُفَّتْ بِالْمَكَارِهِ فَقَالَ اذْهَبْ إِلَيْهَا فَانْظُرْ إِلَيْهَا وَإِلَى مَا أَعْدَدْتُ لأَهْلِهَا فِيهَا فَنَظَرَ إِلَيْهَا فَإِذَا هِيَ قَدْ حُفَّتْ بِالْمَكَارِهِ فَقَالَ وَعِزَّتِكَ لَقَدْ خَشِيتُ أَنْ لاَ يَدْخُلَهَا أَحَدٌ ‏.‏ قَالَ اذْهَبْ فَانْظُرْ إِلَى النَّارِ وَإِلَى مَا أَعْدَدْتُ لأَهْلِهَا فِيهَا ‏.‏ فَنَظَرَ إِلَيْهَا فَإِذَا هِيَ يَرْكَبُ بَعْضُهَا بَعْضًا فَرَجَعَ فَقَالَ وَعِزَّتِكَ لاَ يَدْخُلُهَا أَحَدٌ ‏.‏ فَأَمَرَ بِهَا فَحُفَّتْ بِالشَّهَوَاتِ فَقَالَ ارْجِعْ فَانْظُرْ إِلَيْهَا ‏.‏ فَإِذَا هِيَ قَدْ حُفَّتْ بِالشَّهَوَاتِ فَرَجَعَ وَقَالَ وَعِزَّتِكَ لَقَدْ خَشِيتُ أَنْ لاَ يَنْجُوَ مِنْهَا أَحَدٌ إِلاَّ دَخَلَهَا ‏"‏ ‏.‏\hadithno{3763}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"When Allah created Paradise and Hell, He sent Jibril, peace be upon him, to Paradise and said: 'Look at it and at what I have prepared for its people in it.' He looked at it, then he came back and said: 'By Your Glory, no one will hear of it but he will enter it.' So He commanded that it be surrounded by hardships and said: 'Go and look at it and at what I have prepared for its people in it.' He looked at it and saw that it had been surrounded with hardships. He (Jibril) said: 'By Your Glory, I fear that no one will enter it.' He (Allah) said: 'Go and look at the Fire and at what I have prepared for its people in it.' So he looked at it and parts of it were piled upon other parts. He came back and said: 'By Your Glory, no one will enter it.' So He commanded that it be surrounded with pleasures and said: 'Go and look at it.' So he looked at it and saw that it was surrounded with pleasures. He came back and said: 'By Your Glory, I fear that no one will be saved from it and all will enter it}}
\hadithdefcmd{nasai}{3764}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ، - وَهُوَ ابْنُ جَعْفَرٍ - قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ حَالِفًا فَلاَ يَحْلِفْ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏ وَكَانَتْ قُرَيْشٌ تَحْلِفُ بِآبَائِهَا فَقَالَ ‏"‏ لاَ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏\hadithno{3764}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'Whoever swears, let him not swear by anything other than Allah.'" The Quraish used to swear by their forefathers, and so he said: "Do not swear by your forefathers}}
\hadithdefcmd{nasai}{3765}{أَخْبَرَنِي زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، قَالَ حَدَّثَنِي رَجُلٌ، مِنْ بَنِي غِفَارٍ فِي مَجْلِسِ سَالِمِ بْنِ عَبْدِ اللَّهِ قَالَ سَالِمُ بْنُ عَبْدِ اللَّهِ سَمِعْتُ عَبْدَ اللَّهِ، - يَعْنِي ابْنَ عُمَرَ - وَهُوَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏\hadithno{3765}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Yahya bin Abi Ishaq said:"A man from Banu Ghifar told me, in the gathering of Salim bin 'Abdullah, Salim bin 'Abdullah said: 'I heard 'Abdullah -that is, Ibn 'Umar- say: "The Messenger of Allah said: 'Allah forbids you to swear by your forefathers}}
\hadithdefcmd{nasai}{3766}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَاللَّفْظُ، لَهُ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّبِيُّ صلى الله عليه وسلم عُمَرَ مَرَّةً وَهُوَ يَقُولُ وَأَبِي وَأَبِي ‏.‏ فَقَالَ ‏ "‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏ فَوَاللَّهِ مَا حَلَفْتُ بِهَا بَعْدُ ذَاكِرًا وَلاَ آثِرًا ‏.‏\hadithno{3766}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim, from his father, that on one occasion the Prophet heard 'Umar saying:"By my father and by my mother." He said: "Allah forbids you to swear by your forefathers." 'Umar said: "By Allah, I never swore by them again, whether saying it for myself or reporting it of others}}
\hadithdefcmd{nasai}{3767}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا حَلَفْتُ بِهَا بَعْدُ ذَاكِرًا وَلاَ آثِرًا ‏.‏\hadithno{3767}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Umar that the Prophet said:"Allah forbids you to swear by your forefathers." 'Umar said: "By Allah, I never swore by them again, whether saying it for myself or reporting of others}}
\hadithdefcmd{nasai}{3768}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، قَالَ أَنْبَأَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ حَرْبٍ - عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ عَنْ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا حَلَفْتُ بِهَا بَعْدُ ذَاكِرًا وَلاَ آثِرًا ‏.‏\hadithno{3768}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salim, from his father, that he told him from 'Umar:"The Messenger of Allah said: 'Allah forbids you to swear by your forefathers.'" 'Umar said: "By Allah, I never swore by them again, whether saying it for myself or reporting it of others}}
\hadithdefcmd{nasai}{3769}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا عَوْفٌ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحْلِفُوا بِآبَائِكُمْ وَلاَ بِأُمَّهَاتِكُمْ وَلاَ بِالأَنْدَادِ وَلاَ تَحْلِفُوا إِلاَّ بِاللَّهِ وَلاَ تَحْلِفُوا إِلاَّ وَأَنْتُمْ صَادِقُونَ ‏"‏ ‏.‏\hadithno{3769}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Do not swear by your fathers, nor by your mothers nor by the idols. Swear only by Allah, and do not swear unless you are sincere}}
\hadithdefcmd{nasai}{3770}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ خَالِدٍ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ بِمِلَّةٍ سِوَى الإِسْلاَمِ كَاذِبًا فَهُوَ كَمَا قَالَ ‏"‏ ‏.‏ قَالَ قُتَيْبَةُ فِي حَدِيثِهِ مُتَعَمِّدًا وَقَالَ يَزِيدُ ‏"‏ كَاذِبًا فَهُوَ كَمَا قَالَ وَمَنْ قَتَلَ نَفْسَهُ بِشَىْءٍ عَذَّبَهُ اللَّهُ بِهِ فِي نَارِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{3770}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Thabit bin Ad-Dahhak said:"The Messenger of Allah said: 'Whoever swears by a religion other than Islam, telling a lie, will be as he said.'" In his narration, Qutaibah said: "Intentionally." Yazid said: "Telling a lie will be as he said, and whoever kills himself with something. Allah will punish him with it in the Fire of Hell}}
\hadithdefcmd{nasai}{3771}{أَخْبَرَنِي مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا أَبُو عَمْرٍو، عَنْ يَحْيَى، أَنَّهُ حَدَّثَهُ قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ، قَالَ حَدَّثَنِي ثَابِتُ بْنُ الضَّحَّاكِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ بِمِلَّةٍ سِوَى الإِسْلاَمِ كَاذِبًا فَهُوَ كَمَا قَالَ وَمَنْ قَتَلَ نَفْسَهُ بِشَىْءٍ عُذِّبَ بِهِ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3771}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Thabit bin Ad-Dahhak narrated that the Messenger of Allah said:"Whoever swears by a religion other than Islam, telling a lie, will be as he said, and whoever kills himself with something will be punished with it in the Hereafter}}
\hadithdefcmd{nasai}{3772}{أَخْبَرَنَا الْحُسَيْنِ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ إِنِّي بَرِيءٌ مِنَ الإِسْلاَمِ فَإِنْ كَانَ كَاذِبًا فَهُوَ كَمَا قَالَ وَإِنْ كَانَ صَادِقًا لَمْ يَعُدْ إِلَى الإِسْلاَمِ سَالِمًا ‏"‏ ‏.‏\hadithno{3772}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that his father said:"The Messenger of Allah said: 'Whoever says: I have nothing to do with Islam, if he is lying then he is as he said, and if he is telling the truth, his Islam will not be sound}}
\hadithdefcmd{nasai}{3773}{أَخْبَرَنَا يُوسُفُ بْنُ عِيسَى، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا مِسْعَرٌ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَسَارٍ، عَنْ قُتَيْلَةَ، - امْرَأَةٌ مِنْ جُهَيْنَةَ - أَنَّ يَهُودِيًّا، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّكُمْ تُنَدِّدُونَ وَإِنَّكُمْ تُشْرِكُونَ تَقُولُونَ مَا شَاءَ اللَّهُ وَشِئْتَ وَتَقُولُونَ وَالْكَعْبَةِ ‏.‏ فَأَمَرَهُمُ النَّبِيُّ صلى الله عليه وسلم إِذَا أَرَادُوا أَنْ يَحْلِفُوا أَنْ يَقُولُوا ‏"‏ وَرَبِّ الْكَعْبَةِ ‏"‏ ‏.‏ وَيَقُولُونَ ‏"‏ مَا شَاءَ اللَّهُ ثُمَّ شِئْتَ ‏"‏ ‏.‏\hadithno{3773}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin Yasar, from Qutailah, a woman from Juhainah, that a Jew came to the Prophet and said:"You are setting up rivals (to Allah) and associating others (with Him). You say: 'Whatever Allah wills and you will,' and you say: 'By the Ka'bah.'" So the Prophet commanded them, if they wanted to swear an oath, to say: "By the Lord of the Ka'bah;" and to say: "Whatever Allah wills, then what you will}}
\hadithdefcmd{nasai}{3774}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا هِشَامٌ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَحْلِفُوا بِآبَائِكُمْ وَلاَ بِالطَّوَاغِيتِ ‏"‏ ‏.‏\hadithno{3774}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdur-Rahman bin Samurah that the Prophet said:"Do not swear by your forefathers or by false gods (At-Tawaghit)}}
\hadithdefcmd{nasai}{3775}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ مِنْكُمْ فَقَالَ بِاللاَّتِ فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ وَمَنْ قَالَ لِصَاحِبِهِ تَعَالَ أُقَامِرْكَ فَلْيَتَصَدَّقْ ‏"‏ ‏.‏\hadithno{3775}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever among you swears and says: By Al-Lat, let him say: La ilaha illallah (There is none worthy of worship except Allah). And whoever says to his companion: Come, let us gamble, then let him give in charity}}
\hadithdefcmd{nasai}{3776}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ كُنَّا نَذْكُرُ بَعْضَ الأَمْرِ وَأَنَا حَدِيثُ، عَهْدٍ بِالْجَاهِلِيَّةِ فَحَلَفْتُ بِاللاَّتِ وَالْعُزَّى فَقَالَ لِي أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم بِئْسَ مَا قُلْتَ ائْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبِرْهُ فَإِنَّا لاَ نَرَاكَ إِلاَّ قَدْ كَفَرْتَ فَأَتَيْتُهُ فَأَخْبَرْتُهُ فَقَالَ لِي ‏ "‏ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ ثَلاَثَ مَرَّاتٍ وَتَعَوَّذْ بِاللَّهِ مِنَ الشَّيْطَانِ ثَلاَثَ مَرَّاتٍ وَاتْفُلْ عَنْ يَسَارِكَ ثَلاَثَ مَرَّاتٍ وَلاَ تَعُدْ لَهُ ‏"‏ ‏.‏\hadithno{3776}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mus'ab bin Sa'd that his father said:"We were talking about something, and I had only recently left Jahiliyyah behind, so I swore by Al-Lat and Al-'Uzza. The Companions of the Messenger of Allah said to me: 'What a bad thing you have said! Go to the Messenger of Allah and tell him, for we think that you have committed Kufr.' So I went to him and told him, and he said to me: 'Say: La ilaha illallah wahdahu la sharika lah (There is none worthy of worship except Allah alone, without partner) three times, and seek refuge with Allah from the Shaitan three times, and spit dryly to your left three times, and do not say that again}}
\hadithdefcmd{nasai}{3777}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، قَالَ حَدَّثَنِي مُصْعَبُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، قَالَ حَلَفْتُ بِاللاَّتِ وَالْعُزَّى فَقَالَ لِي أَصْحَابِي بِئْسَ مَا قُلْتَ قُلْتَ هُجْرًا ‏.‏ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ وَانْفُثْ عَنْ يَسَارِكَ ثَلاَثًا وَتَعَوَّذْ بِاللَّهِ مِنَ الشَّيْطَانِ ثُمَّ لاَ تَعُدْ ‏"‏ ‏.‏\hadithno{3777}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mus'ab bin Sa'd narrated that his father said:"I swore by Al-Lat and Al-'Uzza and my companions said to me: 'What a bad thing you have said! You have said something horrible.' So I went to the Messenger of Allah and told him about that. He said: 'Say: La ilaha illallah wahdahu la sharika lah, lahul-mulk wa lahul-hamd wa huwa 'ala kulli shay'in qadir (There is none worthy of worship except Allah with no partner or associate; His is the Dominion, to Him be all praise, and He is able to do all things). Spit to your left three times, seek refuge with Allah from the Shaitan, and do not say that again}}
\hadithdefcmd{nasai}{3778}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَشْعَثِ بْنِ سُلَيْمٍ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعٍ أَمَرَنَا بِاتِّبَاعِ الْجَنَائِزِ وَعِيَادَةِ الْمَرِيضِ وَتَشْمِيتِ الْعَاطِسِ وَإِجَابَةِ الدَّاعِي وَنَصْرِ الْمَظْلُومِ وَإِبْرَارِ الْقَسَمِ وَرَدِّ السَّلاَمِ ‏.‏\hadithno{3778}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Al-Bara' bin 'Azib said:"The Messenger of Allah commanded us to do seven things: He commanded us to attend funerals, visit the sick, to reply (say: Yarhamuk Allah [may Allah have mercy on you]) to one who sneezes, to accept invitations, to support the oppressed, to fulfill oaths (when adjured by another) and to return greetings of Salaam}}
\hadithdefcmd{nasai}{3779}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سُلَيْمَانَ، عَنْ أَبِي السَّلِيلِ، عَنْ زَهْدَمٍ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا عَلَى الأَرْضِ يَمِينٌ أَحْلِفُ عَلَيْهَا فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا إِلاَّ أَتَيْتُهُ ‏"‏ ‏.‏\hadithno{3779}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa that the Prophet said:"There is nothing on Earth that I swear an oath upon, and I see that something else is better, but I do that which is better}}
\hadithdefcmd{nasai}{3780}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ مِنَ الأَشْعَرِيِّينَ نَسْتَحْمِلُهُ فَقَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ وَمَا عِنْدِي مَا أَحْمِلُكُمْ ‏"‏ ‏.‏ ثُمَّ لَبِثْنَا مَا شَاءَ اللَّهُ فَأُتِيَ بِإِبِلٍ فَأَمَرَ لَنَا بِثَلاَثِ ذَوْدٍ فَلَمَّا انْطَلَقْنَا قَالَ بَعْضُنَا لِبَعْضٍ لاَ يُبَارِكُ اللَّهُ لَنَا أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم نَسْتَحْمِلُهُ فَحَلَفَ أَنْ لاَ يَحْمِلَنَا ‏.‏ قَالَ أَبُو مُوسَى فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَذَكَرْنَا ذَلِكَ لَهُ فَقَالَ ‏"‏ مَا أَنَا حَمَلْتُكُمْ بَلِ اللَّهُ حَمَلَكُمْ إِنِّي وَاللَّهِ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا إِلاَّ كَفَّرْتُ عَنْ يَمِينِي وَأَتَيْتُ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{3780}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa Al-Ash'ari said:"I came to the Messenger of Allah with a group of the Ash'ari people and asked him to give us animals to ride. He said: 'By Allah, I cannot give you anything to ride and I have nothing to give you to ride.' We stayed as long as Allah willed, then some camels were brought to him. He ordered that we be given three fine-looking camels. When we left, we said to one another: 'We came to the Messenger of Allah to ask him for animals to ride, and he swore by Allah that he would not give us anything to ride, then he gave us something.'" Abu Musa said: "We came to the Prophet and told him about that. He said: 'I did not give you animals to ride, rather Allah gave you them to ride. By Allah, I do not swear an oath and then see something better than it, but I offer expiation for my oath and do that which is better}}
\hadithdefcmd{nasai}{3781}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، قَالَ حَدَّثَنَا عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيُكَفِّرْ عَنْ يَمِينِهِ وَلْيَأْتِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{3781}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather, that the Messenger of Allah said:"Whoever swears an oath, then sees something better than it, let him do that which is better}}
\hadithdefcmd{nasai}{3782}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا حَلَفَ أَحَدُكُمْ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيُكَفِّرْ عَنْ يَمِينِهِ وَلْيَنْظُرِ الَّذِي هُوَ خَيْرٌ فَلْيَأْتِهِ ‏"‏ ‏.‏\hadithno{3782}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdur-Rahman bin Samurah that the Messenger of Allah said:"If any one of you swears an oath, then he sees something better than it, let him offer expiation for his oath, and look at what is better and do it}}
\hadithdefcmd{nasai}{3783}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ سَمِعْتُ الْحَسَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَلَفْتَ عَلَى يَمِينٍ فَكَفِّرْ عَنْ يَمِينِكَ ثُمَّ ائْتِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{3783}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur-Rahman bin Samurah said:"The Messenger of Allah said: 'If you swear an oath, offer expiation for your oath, then do that which is better}}
\hadithdefcmd{nasai}{3784}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى الْقُطَعِيُّ، عَنْ عَبْدِ الأَعْلَى، وَذَكَرَ، كَلِمَةً مَعْنَاهَا حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا فَكَفِّرْ عَنْ يَمِينِكَ وَائْتِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{3784}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman bin Samurah that the Prophet said:"If you swear an oath, then you see something better than it, then offer expiation for your oath, and do that which is better}}
\hadithdefcmd{nasai}{3785}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، مَوْلَى الْحَسَنِ بْنِ عَلِيٍّ يُحَدِّثُ عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيَأْتِ الَّذِي هُوَ خَيْرٌ وَلْيُكَفِّرْ عَنْ يَمِينِهِ ‏"‏ ‏.‏\hadithno{3785}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"The Messenger of Allah said: 'Whoever swears an oath, then sees something better than it, let him do that which is better and offer expiation for his oath}}
\hadithdefcmd{nasai}{3786}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيَدَعْ يَمِينَهُ وَلْيَأْتِ الَّذِي هُوَ خَيْرٌ وَلْيُكَفِّرْهَا ‏"‏ ‏.‏\hadithno{3786}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"The Messenger of Allah said: 'Whoever swears an oath, then sees something better than it, let him leave his oath, and do that which is better, and offer expiation for it}}
\hadithdefcmd{nasai}{3787}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَبْدُ الْعَزِيزِ بْنُ رُفَيْعٍ، قَالَ سَمِعْتُ تَمِيمَ بْنَ طَرَفَةَ، يُحَدِّثُ عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى خَيْرًا مِنْهَا فَلْيَأْتِ الَّذِي هُوَ خَيْرٌ وَلْيَتْرُكْ يَمِينَهُ ‏"‏ ‏.‏\hadithno{3787}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"The Messenger of Allah said: 'Whoever swears an oath, then sees something better than it, let him do that which is better and leave his oath}}
\hadithdefcmd{nasai}{3788}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا أَبُو الزَّعْرَاءِ، عَنْ عَمِّهِ أَبِي الأَحْوَصِ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ ابْنَ عَمٍّ لِي أَتَيْتُهُ أَسْأَلُهُ فَلاَ يُعْطِينِي وَلاَ يَصِلُنِي ثُمَّ يَحْتَاجُ إِلَىَّ فَيَأْتِينِي فَيَسْأَلُنِي وَقَدْ حَلَفْتُ أَنْ لاَ أُعْطِيَهُ وَلاَ أَصِلَهُ فَأَمَرَنِي أَنْ آتِيَ الَّذِي هُوَ خَيْرٌ وَأُكَفِّرَ عَنْ يَمِينِي ‏.‏\hadithno{3788}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Al-Ahwas that his father said:"I said: 'O Messenger of Allah, I have a cousin, and I come to him and ask him (for help) but he does not give me anything, and he does not uphold the ties of kinship with me. Then, when he needs me, he comes to me and asks me (for help). I swore that I would not give him anything, nor uphold the ties of kinship with him.' He commanded me to do that which is better and to offer expiation for my oath}}
\hadithdefcmd{nasai}{3789}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا مَنْصُورٌ، وَيُونُسُ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا آلَيْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا فَأْتِ الَّذِي هُوَ خَيْرٌ وَكَفِّرْ عَنْ يَمِينِكَ ‏"‏ ‏.‏\hadithno{3789}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdur-Rahman bin Samurah said:"The Prophet said to me: 'If you swear an oath, and you see something that is better, then do that which is better and offer expiation for your oath}}
\hadithdefcmd{nasai}{3790}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ يَعْنِي رَسُولَ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا فَأْتِ الَّذِي هُوَ خَيْرٌ مِنْهَا وَكَفِّرْ عَنْ يَمِينِكَ ‏"‏ ‏.‏\hadithno{3790}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur-Rahman bin Samurah said:"The Messenger of Allah said: 'If you swear an oath, then you see something that is better, then do that which is better and offer expiation for your oath}}
\hadithdefcmd{nasai}{3791}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، فِي حَدِيثِهِ عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنِ الْحَسَنِ الْبَصْرِيِّ، قَالَ عَبْدُ الرَّحْمَنِ بْنُ سَمُرَةَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا فَأْتِ الَّذِي هُوَ خَيْرٌ وَكَفِّرْ عَنْ يَمِينِكَ ‏"‏ ‏.‏\hadithno{3791}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur-Rahman bin Samurah said:"The Messenger of Allah said to me: 'If you swear an oath, then you see something that is better, do that which is better, and offer expiation for your oath}}
\hadithdefcmd{nasai}{3792}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ وَلاَ يَمِينَ فِيمَا لاَ تَمْلِكُ وَلاَ فِي مَعْصِيَةٍ وَلاَ قَطِيعَةِ رَحِمٍ ‏"‏ ‏.‏\hadithno{3792}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather, that the Messenger of Allah said:"There is no vow and no oath concerning that which one does not possess, nor to commit sin, nor to sever the ties of kinship}}
\hadithdefcmd{nasai}{3793}{أَخْبَرَنِي أَحْمَدُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ فَاسْتَثْنَى فَإِنْ شَاءَ مَضَى وَإِنْ شَاءَ تَرَكَ غَيْرَ حَنِثٍ ‏"‏ ‏.‏\hadithno{3793}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet said:"Whoever swears an oath and says: 'If Allah wills', then if he wishes he may go ahead, and if he wishes he may not, without having broken his oath}}
\hadithdefcmd{nasai}{3794}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُلَيْمَانُ بْنُ حَيَّانَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا الأَعْمَالُ بِالنِّيَّةِ وَإِنَّمَا لاِمْرِئٍ مَا نَوَى فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ وَمَنْ كَانَتْ هِجْرَتُهُ لِدُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{3794}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Umar bin Al-Khattab that the Prophet said:"Actions are but by intentions, and each person will have but that which he intended. Thus, he whose emigration was for the sake of Allah and His Messenger, his emigration was for the sake of Allah and His Messenger, and he whose emigration was to achieve some worldly gain or to take some woman in marriage, his emigration was for that for which he emigrated}}
\hadithdefcmd{nasai}{3795}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ زَعَمَ عَطَاءٌ أَنَّهُ سَمِعَ عُبَيْدَ بْنَ عُمَيْرٍ، يَقُولُ سَمِعْتُ عَائِشَةَ، تَزْعُمُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَمْكُثُ عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ فَيَشْرَبُ عِنْدَهَا عَسَلاً فَتَوَاصَيْتُ أَنَا وَحَفْصَةُ أَنَّ أَيَّتَنَا دَخَلَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم فَلْتَقُلْ إِنِّي أَجِدُ مِنْكَ رِيحَ مَغَافِيرَ أَكَلْتَ مَغَافِيرَ فَدَخَلَ عَلَى إِحْدَاهُمَا فَقَالَتْ ذَلِكَ لَهُ فَقَالَ ‏"‏ لاَ بَلْ شَرِبْتُ عَسَلاً عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ وَلَنْ أَعُودَ لَهُ ‏"‏ ‏.‏ فَنَزَلَتْ ‏\{‏ يَا أَيُّهَا النَّبِيُّ لِمَ تُحَرِّمُ مَا أَحَلَّ اللَّهُ لَكَ ‏\}‏ إِلَى ‏\{‏ إِنْ تَتُوبَا إِلَى اللَّهِ ‏\}‏ عَائِشَةُ وَحَفْصَةُ ‏\{‏ وَإِذْ أَسَرَّ النَّبِيُّ إِلَى بَعْضِ أَزْوَاجِهِ حَدِيثًا ‏\}‏ لِقَوْلِهِ ‏"‏ بَلْ شَرِبْتُ عَسَلاً ‏"‏ ‏.‏\hadithno{3795}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{Ubaid bin 'Umair said:I heard 'Aishah say: "The Prophet used to stay with Zainab bint Jahsh and drink honey at her house. Hafsah and I agreed that if the Prophet came to either of us, she would say: 'I detect the smell of Maghafir (a nasty-smelling gum) on you. Have you eaten Maghafir?' He went to one of them and she said that to him. He said: 'No, rather I drank honey at the house of Zainab bint Jahsh, but I will never do it again.' Then the following was revealed: 'O Prophet! Why do you forbid (for yourself) that which Allah has allowed to you' up to: 'If you two turn in repentance to Allah' -'Aishah and Hafsah- 'And (remember) when the Prophet disclosed a matter in confidence to one of his wives.' refers to him saying: 'No, rather I drank honey}}
\hadithdefcmd{nasai}{3796}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا الْمُثَنَّى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ نَافِعٍ، عَنْ جَابِرٍ، قَالَ دَخَلْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بَيْتَهُ فَإِذَا فِلَقٌ وَخَلٌّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلْ فَنِعْمَ الإِدَامُ الْخَلُّ ‏"‏ ‏.‏\hadithno{3796}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"I entered the house of the Prophet with him and there was some bread and vinegar. The Messenger of Allah said: 'Eat; what a good condiment is vinegar}}
\hadithdefcmd{nasai}{3797}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ أَبِي وَائِلٍ، عَنْ قَيْسِ بْنِ أَبِي غَرَزَةَ، قَالَ كُنَّا نُسَمَّى السَّمَاسِرَةَ فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَبِيعُ فَسَمَّانَا بِاسْمٍ هُوَ خَيْرٌ مِنِ اسْمِنَا فَقَالَ ‏ "‏ يَا مَعْشَرَ التُّجَّارِ إِنَّ هَذَا الْبَيْعَ يَحْضُرُهُ الْحَلِفُ وَالْكَذِبُ فَشُوبُوا بَيْعَكُمْ بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{3797}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qais bin Abi Gharazah said:"At the time of the Messenger of Allah we used to be called Samasir (brokers). The Messenger of Allah came to us when we were selling and called us by a name that was better than that. He said: 'O merchants (Tujjar), this selling involves lies and (false) oaths, so mix some charity with it}}
\hadithdefcmd{nasai}{3798}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْمَلِكِ، وَعَاصِمٍ، وَجَامِعٍ، عَنْ أَبِي وَائِلٍ، عَنْ قَيْسِ بْنِ أَبِي غَرَزَةَ، قَالَ كُنَّا نَبِيعُ بِالْبَقِيعِ فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَكُنَّا نُسَمَّى السَّمَاسِرَةَ فَقَالَ ‏"‏ يَا مَعْشَرَ التُّجَّارِ ‏"‏ ‏.‏ فَسَمَّانَا بِاسْمٍ هُوَ خَيْرٌ مِنِ اسْمِنَا ثُمَّ قَالَ ‏"‏ إِنَّ هَذَا الْبَيْعَ يَحْضُرُهُ الْحَلِفُ وَالْكَذِبُ فَشُوبُوهُ بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{3798}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qais bin Abi Gharazah said:"We used to sell in Al-Baqi, and the Messenger of Allah came to us. We used to be called Samasir (brokers) but he said: 'O merchants!' And called us by a name that was better than our name. Then he said: 'This selling involves (false) oaths and lies, so mix some charity with it}}
\hadithdefcmd{nasai}{3799}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مُغِيرَةَ، عَنْ أَبِي وَائِلٍ، عَنْ قَيْسِ بْنِ أَبِي غَرَزَةَ، قَالَ أَتَانَا النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ فِي السُّوقِ فَقَالَ ‏ "‏ إِنَّ هَذِهِ السُّوقَ يُخَالِطُهَا اللَّغْوُ وَالْكَذِبُ فَشُوبُوهَا بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{3799}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qais bin Abi Gharazah said:"The Prophet came to us when we were in the marketplace and said: 'This marketplace is filled with idle talk and (false) oaths, so mix some charity with it}}
\hadithdefcmd{nasai}{3800}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، وَمُحَمَّدُ بْنُ قُدَامَةَ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ قَيْسِ بْنِ أَبِي غَرَزَةَ، قَالَ كُنَّا بِالْمَدِينَةِ نَبِيعُ الأَوْسَاقَ وَنَبْتَاعُهَا وَكُنَّا نُسَمِّي أَنْفُسَنَا السَّمَاسِرَةَ وَيُسَمِّينَا النَّاسُ فَخَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَسَمَّانَا بِاسْمٍ هُوَ خَيْرٌ مِنَ الَّذِي سَمَّيْنَا أَنْفُسَنَا وَسَمَّانَا النَّاسُ فَقَالَ ‏ "‏ يَا مَعْشَرَ التُّجَّارِ إِنَّهُ يَشْهَدُ بَيْعَكُمُ الْحَلِفُ وَالْكَذِبُ فَشُوبُوهُ بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{3800}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qais bin Abi Gharazah said:"In Al-Madinah we used to buy and sell Wasqs (of goods), and we used to call ourselves Samasir (brokers), and the people used to call us like that. The Messenger of Allah came out to us one day, and called us by a name that was better than that which we called ourselves and which the people called us. He said: 'O Tujjar (traders), your selling involves (false) oaths and lies, so mix some charity with it}}
\hadithdefcmd{nasai}{3801}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، قَالَ أَخْبَرَنِي مَنْصُورٌ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ النَّذْرِ وَقَالَ ‏ "‏ إِنَّهُ لاَ يَأْتِي بِخَيْرٍ إِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏.‏\hadithno{3801}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Messenger of Allah forbade vows and said:"They do not bring any good; they are just a means of taking wealth from the miserly}}
\hadithdefcmd{nasai}{3802}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ النَّذْرِ وَقَالَ ‏ "‏ إِنَّهُ لاَ يَرُدُّ شَيْئًا إِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الشَّحِيحِ ‏"‏ ‏.‏\hadithno{3802}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"The Messenger of Allah forbade vows and said: 'They do not change anything; they are just a means of taking wealth from the miserly}}
\hadithdefcmd{nasai}{3803}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ النَّذْرُ لاَ يُقَدِّمُ شَيْئًا وَلاَ يُؤَخِّرُهُ إِنَّمَا هُوَ شَىْءٌ يُسْتَخْرَجُ بِهِ مِنَ الشَّحِيحِ ‏"‏ ‏.‏\hadithno{3803}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'A vow does not bring anything forward or put it back; it is just a means of taking wealth from the miserly}}
\hadithdefcmd{nasai}{3804}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَأْتِي النَّذْرُ عَلَى ابْنِ آدَمَ شَيْئًا لَمْ يُقَدِّرْهُ عَلَيْهِ وَلَكِنَّهُ شَىْءٌ يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏.‏\hadithno{3804}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"A vow does not bring anything to the son of Adam that has not been decreed for him. It is just a means of taking wealth from the miserly}}
\hadithdefcmd{nasai}{3805}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنْذِرُوا فَإِنَّ النَّذْرَ لاَ يُغْنِي مِنَ الْقَدَرِ شَيْئًا وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏.‏\hadithno{3805}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Do not make vows, for a vow does not have any impact on the Qadar. Rather it is just a means of taking wealth from the miserly}}
\hadithdefcmd{nasai}{3806}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ الْمَلِكِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نَذَرَ أَنْ يُطِيعَ اللَّهَ فَلْيُطِعْهُ وَمَنْ نَذَرَ أَنْ يَعْصِيَ اللَّهَ فَلاَ يَعْصِهِ ‏"‏ ‏.‏\hadithno{3806}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"Whoever vows to obey Allah, let him obey Him, and whoever vows to disobey Allah, let him not disobey Him}}
\hadithdefcmd{nasai}{3807}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا مَالِكٌ، قَالَ حَدَّثَنِي طَلْحَةُ بْنُ عَبْدِ الْمَلِكِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ نَذَرَ أَنْ يُطِيعَ اللَّهَ فَلْيُطِعْهُ وَمَنْ نَذَرَ أَنْ يَعْصِيَ اللَّهَ فَلاَ يَعْصِهِ ‏"‏ ‏.‏\hadithno{3807}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"I heard the Messenger of Allah say: 'Whoever vows to obey Allah, let him obey Him, and whoever vows to disobey Allah, let him not disobey Him}}
\hadithdefcmd{nasai}{3808}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ طَلْحَةَ بْنِ عَبْدِ الْمَلِكِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ نَذَرَ أَنْ يُطِيعَ اللَّهَ فَلْيُطِعْهُ وَمَنْ نَذَرَ أَنْ يَعْصِيَ اللَّهَ فَلاَ يَعْصِهِ ‏"‏ ‏.‏\hadithno{3808}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"I heard the Messenger of Allah say: 'Whoever vows to obey Allah, let him obey Him, and whoever vows to disobey Allah, let him not disobey Him}}
\hadithdefcmd{nasai}{3809}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي جَمْرَةَ، عَنْ زَهْدَمٍ، قَالَ سَمِعْتُ عِمْرَانَ بْنَ حُصَيْنٍ، يَذْكُرُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُكُمْ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ فَلاَ أَدْرِي أَذَكَرَ مَرَّتَيْنِ بَعْدَهُ أَوْ ثَلاَثًا ثُمَّ ذَكَرَ قَوْمًا يَخُونُونَ وَلاَ يُؤْتَمَنُونَ وَيَشْهَدُونَ وَلاَ يُسْتَشْهَدُونَ وَيُنْذِرُونَ وَلاَ يُوفُونَ وَيَظْهَرُ فِيهِمُ السِّمَنُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا نَصْرُ بْنُ عِمْرَانَ أَبُو جَمْرَةَ ‏.‏\hadithno{3809}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Imran bin Husain said:"The Messenger of Allah said: 'The best of you are my generation, then those who come after them, then those whom after them, then those who come after them.' -I do not know if he said two times after him or three. Then he mentioned some people who betray and cannot be trusted, who bear witness without being asked to do so, who make vows and do not fulfill them, and fatness will prevail among them}}
\hadithdefcmd{nasai}{3810}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي سُلَيْمَانُ الأَحْوَلُ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَجُلٍ يَقُودُ رَجُلاً فِي قَرَنٍ فَتَنَاوَلَهُ النَّبِيُّ صلى الله عليه وسلم فَقَطَعَهُ قَالَ إِنَّهُ نَذْرٌ ‏.‏\hadithno{3810}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah passed by a man who was leading another man by a rope. The Prophet took it, and cut it, and he said: 'It is a vow}}
\hadithdefcmd{nasai}{3811}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي سُلَيْمَانُ الأَحْوَلُ، أَنَّ طَاوُسًا، أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِرَجُلٍ وَهُوَ يَطُوفُ بِالْكَعْبَةِ يَقُودُهُ إِنْسَانٌ بِخِزَامَةٍ فِي أَنْفِهِ فَقَطَعَهُ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ ثُمَّ أَمَرَهُ أَنْ يَقُودَهُ بِيَدِهِ ‏.‏ قَالَ ابْنُ جُرَيْجٍ وَأَخْبَرَنِي سُلَيْمَانُ أَنَّ طَاوُسًا أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِهِ وَهُوَ يَطُوفُ بِالْكَعْبَةِ وَإِنْسَانٌ قَدْ رَبَطَ يَدَهُ بِإِنْسَانٍ آخَرَ بِسَيْرٍ أَوْ خَيْطٍ أَوْ بِشَىْءٍ غَيْرِ ذَلِكَ فَقَطَعَهُ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ ثُمَّ قَالَ ‏ "‏ قُدْهُ بِيَدِكَ ‏"‏ ‏.‏\hadithno{3811}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas:"The Prophet passed by a man who was circumambulating the Ka'bah, led by another man with a reign in his nose. The Prophet took him by the hand and commanded him to lead him by his hand." Ibn Juraij said: "Sulaiman told me that Tawus told him, from Ibn 'Abbas, that the Prophet passed by him when he was circumambulating the Ka'bah, and a man had tied his hand to another man with some string or thread or whatever. The Prophet cut it with his hand then said: 'Lead him with your hand}}
\hadithdefcmd{nasai}{3812}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي أَيُّوبُ، قَالَ حَدَّثَنَا أَبُو قِلاَبَةَ، عَنْ عَمِّهِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةِ اللَّهِ وَلاَ فِيمَا لاَ يَمْلِكُ ابْنُ آدَمَ ‏"‏ ‏.‏\hadithno{3812}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Imran bin Husain that the Prophet said:"There is no vow to commit an act of disobedience, and no vow concerning that which the son of Adam does not possess}}
\hadithdefcmd{nasai}{3813}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو الْمُغِيرَةِ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ بِمِلَّةٍ سِوَى مِلَّةِ الإِسْلاَمِ كَاذِبًا فَهُوَ كَمَا قَالَ وَمَنْ قَتَلَ نَفْسَهُ بِشَىْءٍ فِي الدُّنْيَا عُذِّبَ بِهِ يَوْمَ الْقِيَامَةِ وَلَيْسَ عَلَى رَجُلٍ نَذْرٌ فِيمَا لاَ يَمْلِكُ ‏"‏ ‏.‏\hadithno{3813}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Thabit bin Ad-Dahhak, that the Messenger of Allah said:"Whoever swears by a religion other than Islam, telling a lie, will be as he said, and whoever kills himself with something, he will be punished with it in the Hereafter, and there is no vow concerning that which a man does not possess}}
\hadithdefcmd{nasai}{3814}{أَخْبَرَنِي يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَخْبَرَهُ أَنَّ أَبَا الْخَيْرِ حَدَّثَهُ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ نَذَرَتْ أُخْتِي أَنْ تَمْشِيَ، إِلَى بَيْتِ اللَّهِ فَأَمَرَتْنِي أَنْ أَسْتَفْتِيَ لَهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَفْتَيْتُ لَهَا النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لِتَمْشِ وَلْتَرْكَبْ ‏"‏ ‏.‏\hadithno{3814}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"My sister vowed to walk to the House of Allah, and she told me to ask the Messenger of Allah about that. So I asked the Prophet for her and he said: 'Let her walk, and let her ride}}
\hadithdefcmd{nasai}{3815}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، - وَقَالَ عَمْرٌو إِنَّ عُبَيْدَ اللَّهِ بْنَ زَحْرٍ أَخْبَرَهُ - عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ، أَنَّ عُقْبَةَ بْنَ عَامِرٍ، أَخْبَرَهُ أَنَّهُ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ أُخْتٍ لَهُ نَذَرَتْ أَنْ تَمْشِيَ حَافِيَةً غَيْرَ مُخْتَمِرَةٍ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مُرْهَا فَلْتَخْتَمِرْ وَلْتَرْكَبْ وَلْتَصُمْ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏\hadithno{3815}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Uqbah bin 'Amir narrated that he asked the Prophet about a sister of his who had vowed to walk, barefoot and bareheaded. The Prophet said to him:"Tell her to cover her head and ride, and fast for three days}}
\hadithdefcmd{nasai}{3816}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ الْعَسْكَرِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، قَالَ سَمِعْتُ سُلَيْمَانَ، يُحَدِّثُ عَنْ مُسْلِمٍ الْبَطِينِ، عَنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَكِبَتِ امْرَأَةٌ الْبَحْرَ فَنَذَرَتْ أَنْ تَصُومَ شَهْرًا فَمَاتَتْ قَبْلَ أَنْ تَصُومَ فَأَتَتْ أُخْتُهَا النَّبِيَّ صلى الله عليه وسلم وَذَكَرَتْ ذَلِكَ لَهُ فَأَمَرَهَا أَنْ تَصُومَ عَنْهَا ‏.‏\hadithno{3816}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"A woman traveled by sea and vowed to fast for a month, but she died before she could fast. Her sister came to the Prophet and told him about that, and he told her to fast on her behalf}}
\hadithdefcmd{nasai}{3817}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، اسْتَفْتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ تُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ فَقَالَ ‏ "‏ اقْضِهِ عَنْهَا ‏"‏ ‏.‏\hadithno{3817}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that Sa'd bin 'Ubadah asked the Messenger of Allah about a vow which his mother had sworn, but she died before she could fulfill it. He said:"Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3818}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ اسْتَفْتَى سَعْدُ بْنُ عُبَادَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ فَتُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏ ‏.‏\hadithno{3818}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"Sa'd bin 'Ubadah asked the Messenger of Allah about a vow which his mother had sworn, but she died before she could fulfill it. The Messenger of Allah said: 'Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3819}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، وَهَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، عَنْ عَبْدَةَ، عَنْ هِشَامٍ، - وَهُوَ ابْنُ عُرْوَةَ - عَنْ بَكْرِ بْنِ وَائِلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ سَعْدُ بْنُ عُبَادَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا نَذْرٌ فَلَمْ تَقْضِهِ ‏.‏ قَالَ ‏ "‏ اقْضِهِ عَنْهَا ‏"‏ ‏.‏\hadithno{3819}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"Sa'd bin 'Ubadah came to the Prophet and said: 'My mother died and she had sworn a vow, but she did not fulfill it.' He said: 'Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3820}{أَخْبَرَنَا إِسْحَاقُ بْنُ مُوسَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، أَنَّهُ كَانَ عَلَيْهِ لَيْلَةٌ نَذَرَ فِي الْجَاهِلِيَّةِ يَعْتَكِفُهَا فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يَعْتَكِفَ ‏.‏\hadithno{3820}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar, that 'Umar had vowed to spend a night in 'Itikaf during the Jahiliyyah. He asked the Messenger of Allah about that, and he ordered him to perform the 'Itikaf}}
\hadithdefcmd{nasai}{3821}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ عَلَى عُمَرَ نَذْرٌ فِي اعْتِكَافِ لَيْلَةٍ فِي الْمَسْجِدِ الْحَرَامِ فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَمَرَهُ أَنْ يَعْتَكِفَ ‏.‏\hadithno{3821}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"Umar had made a vow to spend a night in 'Itikaf in Al-Masjid Al-Haram. He asked the Messenger of Allah about that, and he ordered him to perform the 'Itikaf}}
\hadithdefcmd{nasai}{3822}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، كَانَ جَعَلَ عَلَيْهِ يَوْمًا يَعْتَكِفُهُ فِي الْجَاهِلِيَّةِ فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَمَرَهُ أَنْ يَعْتَكِفَهُ ‏.‏\hadithno{3822}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that 'Umar had vowed -during the Jahiliyyah- to spend a day in 'Itikaf. He asked the Messenger of Allah about that, and he commanded him to perform the 'Itikaf}}
\hadithdefcmd{nasai}{3823}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ تِيبَ عَلَيْهِ يَا رَسُولَ اللَّهِ إِنِّي أَنْخَلِعُ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَرَسُولِهِ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمْسِكْ عَلَيْكَ بَعْضَ مَالِكَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ يُشْبِهُ أَنْ يَكُونَ الزُّهْرِيُّ سَمِعَ هَذَا الْحَدِيثَ مِنْ عَبْدِ اللَّهِ بْنِ كَعْبٍ وَمِنْ عَبْدِ الرَّحْمَنِ عَنْهُ فِي هَذَا الْحَدِيثِ الطَّوِيلِ تَوْبَةُ كَعْبٍ ‏.‏\hadithno{3823}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Ka'b bin Malik narrated from his father, that he said to the Messenger of Allah -when his repentance was accepted:"O Messenger of Allah! I want to give all my wealth in charity for Allah and His Messenger." The Messenger of Allah said to him: "Keep some of your wealth for yourself; that is better for you}}
\hadithdefcmd{nasai}{3824}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، قَالَ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، يُحَدِّثُ حَدِيثَهُ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ قَالَ فَلَمَّا جَلَسْتُ بَيْنَ يَدَيْهِ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ مِنْ تَوْبَتِي أَنْ أَنْخَلِعَ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَإِلَى رَسُولِهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمْسِكْ عَلَيْكَ بَعْضَ مَالِكَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ فَقُلْتُ فَإِنِّي أُمْسِكُ سَهْمِي الَّذِي بِخَيْبَرَ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{3824}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur-Rahman bin Ka'b bin Malik narrated that 'Abdullah bin Ka'b said:"I heard Ka'b bin Malik narrating his Hadith about when he stayed behind and did not join the Messenger of Allah on the campaign to Tabuk. He said: 'When I sat down before him I said: "O Messenger of Allah, as part of my repentance I want to give my wealth in charity to Allah and His Messenger." The Messenger of Allah said: "Keep some of your wealth for yourself; that is better for you." I said: "I will keep my share that is in Khaibar}}
\hadithdefcmd{nasai}{3825}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، يُحَدِّثُ حَدِيثَهُ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ مِنْ تَوْبَتِي أَنْ أَنْخَلِعَ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَإِلَى رَسُولِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمْسِكْ عَلَيْكَ مَالَكَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قُلْتُ فَإِنِّي أُمْسِكُ عَلَىَّ سَهْمِي الَّذِي بِخَيْبَرَ ‏.‏\hadithno{3825}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Ka'b bin Malik said:"I heard Ka'b bin Malik narrating his Hadith about when he stayed behind and did not join the Messenger of Allah on the campaign to Tabuk. (he said) I said: 'As part of my repentance I want to give my wealth in charity for Allah and His Messenger.' The Messenger of Allah said: 'Keep some of your wealth for yourself; that is better for you.' I said: 'I will keep for myself my share that is in Khaibar}}
\hadithdefcmd{nasai}{3826}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْدَانَ بْنِ عِيسَى، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، قَالَ حَدَّثَنَا مَعْقِلٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبٍ، عَنْ عَمِّهِ، عُبَيْدِ اللَّهِ بْنِ كَعْبٍ قَالَ سَمِعْتُ أَبِي كَعْبَ بْنَ مَالِكٍ، يُحَدِّثُ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ عَزَّ وَجَلَّ إِنَّمَا نَجَّانِي بِالصِّدْقِ وَإِنَّ مِنْ تَوْبَتِي أَنْ أَنْخَلِعَ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَإِلَى رَسُولِهِ ‏.‏ فَقَالَ ‏ "‏ أَمْسِكْ عَلَيْكَ بَعْضَ مَالِكَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قُلْتُ فَإِنِّي أُمْسِكُ سَهْمِي الَّذِي بِخَيْبَرَ ‏.‏\hadithno{3826}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ubaydullah bin Ka'b:"I heard my father Ka'b bin Malik narrate: 'I said: O Messenger of Allah, Allah, the Mighty and Sublime, has saved me by my being truthful, and as part of my repentance I want to give my wealth in charity to Allah and His Messenger. He said: Keep some of your wealth for yourself; that is better for you. I said: I will keep my share that is in Khaibar}}
\hadithdefcmd{nasai}{3827}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، مَوْلَى ابْنِ مُطِيعٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ خَيْبَرَ فَلَمْ نَغْنَمْ إِلاَّ الأَمْوَالَ وَالْمَتَاعَ وَالثِّيَابَ فَأَهْدَى رَجُلٌ مِنْ بَنِي الضُّبَيْبِ يُقَالُ لَهُ رِفَاعَةُ بْنُ زَيْدٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم غُلاَمًا أَسْوَدَ يُقَالُ لَهُ مِدْعَمٌ فَوُجِّهَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى وَادِي الْقُرَى حَتَّى إِذَا كُنَّا بِوَادِي الْقُرَى بَيْنَا مِدْعَمٌ يَحُطُّ رَحْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَهُ سَهْمٌ فَأَصَابَهُ فَقَتَلَهُ فَقَالَ النَّاسُ هَنِيئًا لَكَ الْجَنَّةُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَلاَّ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّ الشَّمْلَةَ الَّتِي أَخَذَهَا يَوْمَ خَيْبَرَ مِنَ الْمَغَانِمِ لَتَشْتَعِلُ عَلَيْهِ نَارًا ‏"‏ ‏.‏ فَلَمَّا سَمِعَ النَّاسُ بِذَلِكَ جَاءَ رَجُلٌ بِشِرَاكٍ أَوْ بِشِرَاكَيْنِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شِرَاكٌ أَوْ شِرَاكَانِ مِنْ نَارٍ ‏"‏ ‏.‏\hadithno{3827}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"We were with the Messenger of Allah in the year of Khaibar, and we did not get any spoils of war except for wealth, goods and clothes. Then a man from Banu Ad-Dubaib, who was called Rifa'ah bin Zaid, gave the Messenger of Allah a black slave who was called Mid'am. The Messenger of Allah set out for Wadi Al-Qura. When we were in Wadi Al-Qura, while Mid'am was unloading the luggage of the Messenger of Allah, an arrow came and killed him. The people said: 'Congratulations! You will go to Paradise,' but the Messenger of Allah said: 'No, by the One in Whose hand is my soul! The cloak that he took from the spoils of war on the Day of Khaibar is burning him with fire.' When the people heard that, a man brought one or two shoelaces to the Messenger of Allah and the Messenger of Allah said: 'One or two shoelaces of fire}}
\hadithdefcmd{nasai}{3828}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ كَثِيرَ بْنَ فَرْقَدٍ، حَدَّثَهُ أَنَّ نَافِعًا حَدَّثَهُمْ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ فَقَالَ إِنْ شَاءَ اللَّهُ فَقَدِ اسْتَثْنَى ‏"‏ ‏.‏\hadithno{3828}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin 'Umar said:"The Messenger of Allah said: 'Whoever swears an oath and says: If Allah wills, then he has made an exception}}
\hadithdefcmd{nasai}{3829}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ فَقَالَ إِنْ شَاءَ اللَّهُ فَقَدِ اسْتَثْنَى ‏"‏ ‏.‏\hadithno{3829}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'Whoever swears an oath and says: If Allah wills, then he has made an exception}}
\hadithdefcmd{nasai}{3830}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَقَالَ إِنْ شَاءَ اللَّهُ فَهُوَ بِالْخِيَارِ إِنْ شَاءَ أَمْضَى وَإِنْ شَاءَ تَرَكَ ‏"‏ ‏.‏\hadithno{3830}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah said:"Whoever swears an oath and says, 'If Allah wills,' then he has the choice: If he wishes, he may go ahead, and if he wishes he may not}}
\hadithdefcmd{nasai}{3831}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ أَنْبَأَنَا شُعَيْبٌ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، مِمَّا حَدَّثَهُ عَبْدُ الرَّحْمَنِ الأَعْرَجُ، مِمَّا ذَكَرَ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ بِهِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ لأَطُوفَنَّ اللَّيْلَةَ عَلَى تِسْعِينَ امْرَأَةً كُلُّهُنَّ يَأْتِي بِفَارِسٍ يُجَاهِدُ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ فَقَالَ لَهُ صَاحِبُهُ إِنْ شَاءَ اللَّهُ ‏.‏ فَلَمْ يَقُلْ إِنْ شَاءَ اللَّهُ فَطَافَ عَلَيْهِنَّ جَمِيعًا فَلَمْ تَحْمِلْ مِنْهُنَّ إِلاَّ امْرَأَةٌ وَاحِدَةٌ جَاءَتْ بِشِقِّ رَجُلٍ وَايْمُ الَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْ قَالَ إِنْ شَاءَ اللَّهُ لَجَاهَدُوا فِي سَبِيلِ اللَّهِ فُرْسَانًا أَجْمَعِينَ ‏"‏ ‏.‏\hadithno{3831}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Sulaiman bin Dawud said: 'Tonight I will go around ninety women, each of whom will bear a horseman who will perform Jihad in the cause of Allah.' His companion said to him: 'If Allah wills.' But he did not say: 'If Allah wills.' Then he went around to them all, but none of them got pregnant except a woman who bore half a man. By the One in Whose Hand is my soul! If he had said, 'If Allah wills,' they would all have performed Jihad in the cause of Allah as horsemen}}
\hadithdefcmd{nasai}{3832}{أَخْبَرَنَا أَحْمَدُ بْنُ يَحْيَى بْنِ الْوَزِيرِ بْنِ سُلَيْمَانَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ كَعْبِ بْنِ عَلْقَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شِمَاسَةَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَفَّارَةُ النَّذْرِ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏\hadithno{3832}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that the Messenger of Allah said:"The expiation for vows is the expiation for an oath}}
\hadithdefcmd{nasai}{3833}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، أَنَّهُ بَلَغَهُ عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ ‏"‏ ‏.‏\hadithno{3833}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'There is no vow to commit an act of disobedience}}
\hadithdefcmd{nasai}{3834}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهُ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏\hadithno{3834}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"There is no vow to commit an act of disobedience and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3835}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{3835}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'There is no vow to commit an act of disobedience, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3836}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{3836}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"There is no vow to commit an act of disobedience, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3837}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو صَفْوَانَ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهُ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَقَدْ قِيلَ إِنَّ الزُّهْرِيَّ لَمْ يَسْمَعْ هَذَا مِنْ أَبِي سَلَمَةَ ‏.‏\hadithno{3837}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'There is no vow to commit an act of disobedience, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3838}{أَخْبَرَنَا هَارُونُ بْنُ مُوسَى الْفَرْوِيُّ، قَالَ حَدَّثَنَا أَبُو ضَمْرَةَ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهَا كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏\hadithno{3838}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"There is no vow to commit an act of disobedience, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3839}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ التِّرْمِذِيُّ، قَالَ حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ مُحَمَّدِ بْنِ أَبِي عَتِيقٍ، وَمُوسَى بْنِ عُقْبَةَ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ أَرْقَمَ، أَنَّ يَحْيَى بْنَ أَبِي كَثِيرٍ الَّذِي، كَانَ يَسْكُنُ الْيَمَامَةَ حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا سَلَمَةَ، يُخْبِرُ عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهَا كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ سُلَيْمَانُ بْنُ أَرْقَمَ مَتْرُوكُ الْحَدِيثِ وَاللَّهُ أَعْلَمُ ‏.‏ خَالَفَهُ غَيْرُ وَاحِدٍ مِنْ أَصْحَابِ يَحْيَى بْنِ أَبِي كَثِيرٍ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{3839}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"There is no vow to commit an act of disobedience, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3840}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنِ ابْنِ الْمُبَارَكِ، - وَهُوَ عَلِيٌّ - عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ الْحَنْظَلِيِّ، عَنْ أَبِيهِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{3840}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Imran bin Husain said:"The Messenger of Allah said: 'There is no vow to commit an act of disobedience, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3841}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ أَبِي عَمْرٍو، - وَهُوَ الأَوْزَاعِيُّ - عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ الْحَنْظَلِيِّ، عَنْ أَبِيهِ، عَنِ عِمْرَانَ بْنِ حُصَيْنٍ، رضى الله عنهما قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهَا كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{3841}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Imran bin Husain, may Allah be pleased with him, said:"The Messenger of Allah said: 'There is no vow to commit an act of disobedience, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3842}{أَخْبَرَنَا عَلِيُّ بْنُ مَيْمُونٍ، قَالَ حَدَّثَنَا مَعْمَرُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ بِشْرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدٍ الْحَنْظَلِيِّ، عَنْ أَبِيهِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي غَضَبٍ وَكَفَّارَتُهُ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ مُحَمَّدُ بْنُ الزُّبَيْرِ ضَعِيفٌ لاَ يَقُومُ بِمِثْلِهِ حُجَّةٌ ‏.‏ وَقَدِ اخْتُلِفَ عَلَيْهِ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{3842}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Imran bin Husain said:"The Messenger of Allah said: 'There is no vow at a moment of anger and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3843}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ عِمْرَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي غَضَبٍ وَكَفَّارَتُهُ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏\hadithno{3843}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Imran said:The Messenger of Allah said: "There is no vow at a moment of anger and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3844}{أَخْبَرَنَا قُتَيْبَةُ، أَنْبَأَنَا حَمَّادٌ، عَنْ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عِمْرَانَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي غَضَبٍ وَكَفَّارَتُهُ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏ وَقِيلَ إِنَّ الزُّبَيْرَ لَمْ يَسْمَعْ هَذَا الْحَدِيثَ مِنْ عِمْرَانَ بْنِ حُصَيْنٍ ‏.‏\hadithno{3844}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Imran said:The Messenger of Allah said: "There is no vow at a moment of anger and its expiation is the expiation for an oath." It was said: "Az-Zubair did not hear this Hadith from 'Imran bin Husain}}
\hadithdefcmd{nasai}{3845}{أَخْبَرَنِي مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي ابْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ رَجُلٍ، مِنْ أَهْلِ الْبَصْرَةِ قَالَ صَحِبْتُ عِمْرَانَ بْنَ حُصَيْنٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ النَّذْرُ نَذْرَانِ فَمَا كَانَ مِنْ نَذْرٍ فِي طَاعَةِ اللَّهِ فَذَلِكَ لِلَّهِ وَفِيهِ الْوَفَاءُ وَمَا كَانَ مِنْ نَذْرٍ فِي مَعْصِيَةِ اللَّهِ فَذَلِكَ لِلشَّيْطَانِ وَلاَ وَفَاءَ فِيهِ وَيُكَفِّرُهُ مَا يُكَفِّرُ الْيَمِينَ ‏"‏ ‏.‏\hadithno{3845}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muhammad bin Az-Zubair, from his father, from a man from the inhabitants of Al-Basrah, who said:"I accompanied 'Imran bin Husain, who said: 'I heard the Messenger of Allah say: Vows are of two types: A vow that is made to do an act of obedience to Allah; that is for Allah and must be fulfilled, and a vow that is made to do an act of disobedience to Allah; that is for Shaitan and should not be fulfilled, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3846}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ الْحَنْظَلِيِّ، قَالَ أَخْبَرَنِي أَبِي أَنَّ رَجُلاً، حَدَّثَهُ أَنَّهُ، سَأَلَ عِمْرَانَ بْنَ حُصَيْنٍ عَنْ رَجُلٍ، نَذَرَ نَذْرًا لاَ يَشْهَدُ الصَّلاَةَ فِي مَسْجِدِ قَوْمِهِ فَقَالَ عِمْرَانُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ نَذْرَ فِي غَضَبٍ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{3846}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Muhammad bin Az-Zubayr Hanzali said:My father told me that a man told him, that he asked 'Imran bin Husain about a man who made a vow not to attend the prayers in the mosque of his people. 'Imran said: I heard the Messenger of Allah say: There is no vow at a moment of anger and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3847}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَلاَ غَضَبٍ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{3847}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Imran bin Husain said:The Messenger of Allah said: "There is no vow to commit an act of disobedience or at the time of anger, and its expiation is the expiation for an oath}}
\hadithdefcmd{nasai}{3848}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو سُلَيْمٍ، - وَهُوَ عُبَيْدُ بْنُ يَحْيَى - قَالَ حَدَّثَنَا أَبُو بَكْرٍ النَّهْشَلِيُّ، عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي الْمَعْصِيَةِ وَكَفَّارَتُهُ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏ خَالَفَهُ مَنْصُورُ بْنُ زَاذَانَ فِي لَفْظِهِ ‏.‏\hadithno{3848}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Imran bin Husain said:The Messenger of Allah said: "There is no vow to commit an act of disobedience and its expiation is the expiation for an oath." Mansur bin Zadhan contradicted him in his wording}}
\hadithdefcmd{nasai}{3849}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا مَنْصُورٌ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ لاِبْنِ آدَمَ فِيمَا لاَ يَمْلِكُ وَلاَ فِي مَعْصِيَةِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ خَالَفَهُ عَلِيُّ بْنُ زَيْدٍ فَرَوَاهُ عَنِ الْحَسَنِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ ‏.‏\hadithno{3849}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Imran bin Husain said:The Messenger of Allah said: "There is no vow for the son of Adam with regard to that which he does not possess, or to do an act of disobedience to Allah, the Mighty and Sublime." 'Ali bin Zaid contradicted him -for he reported it from Al-Hasan from 'Abdur-Rahman bin Samurah}}
\hadithdefcmd{nasai}{3850}{أَخْبَرَنِي عَلِيُّ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ، قَالَ حَدَّثَنَا خَلَفُ بْنُ تَمِيمٍ، قَالَ حَدَّثَنَا زَائِدَةُ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَلاَ فِيمَا لاَ يَمْلِكُ ابْنُ آدَمَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عَلِيُّ بْنُ زَيْدٍ ضَعِيفٌ وَهَذَا الْحَدِيثُ خَطَأٌ وَالصَّوَابُ عِمْرَانُ بْنُ حُصَيْنٍ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ مِنْ وَجْهٍ آخَرَ ‏.‏\hadithno{3850}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin Samurah that the Prophet said:"There is no vow to commit an act of disobedience or with regard to that which the son of Adam does not possess}}
\hadithdefcmd{nasai}{3851}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي أَيُّوبُ، قَالَ حَدَّثَنَا أَبُو قِلاَبَةَ، عَنْ عَمِّهِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَلاَ فِيمَا لاَ يَمْلِكُ ابْنُ آدَمَ ‏"‏ ‏.‏\hadithno{3851}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Imran bin Husain said:The Messenger of Allah said: "There is no vow to commit an act of disobedience or with regard to that which the son of Adam does not possess}}
\hadithdefcmd{nasai}{3852}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنْ حُمَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ رَأَى النَّبِيُّ صلى الله عليه وسلم رَجُلاً يُهَادَى بَيْنَ رَجُلَيْنِ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالُوا نَذَرَ أَنْ يَمْشِيَ إِلَى بَيْتِ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ غَنِيٌّ عَنْ تَعْذِيبِ هَذَا نَفْسَهُ مُرْهُ فَلْيَرْكَبْ ‏"‏ ‏.‏\hadithno{3852}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Prophet saw a man being supported by two others and said: 'What is this?' They said: 'He vowed to walk to the House of Allah.' He said: 'Allah has no need for this man to torture himself. Tell him to ride}}
\hadithdefcmd{nasai}{3853}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَيْخٍ يُهَادَى بَيْنَ اثْنَيْنِ فَقَالَ ‏"‏ مَا بَالُ هَذَا ‏"‏ ‏.‏ قَالُوا نَذَرَ أَنْ يَمْشِيَ ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ غَنِيٌّ عَنْ تَعْذِيبِ هَذَا نَفْسَهُ مُرْهُ فَلْيَرْكَبْ ‏"‏ ‏.‏ فَأَمَرَهُ أَنْ يَرْكَبَ ‏.‏\hadithno{3853}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah passed by an old man who was being supported between two men and said: 'What is the matter with him?' They said: 'He vowed to walk.' He said: 'Allah has no need for him to torture himself. Tell him to ride.'" So he was told to ride}}
\hadithdefcmd{nasai}{3854}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رَجُلٍ يُهَادَى بَيْنَ ابْنَيْهِ فَقَالَ ‏"‏ مَا شَأْنُ هَذَا ‏"‏ ‏.‏ فَقِيلَ نَذَرَ أَنْ يَمْشِيَ إِلَى الْكَعْبَةِ ‏.‏ فَقَالَ ‏"‏ إِنَّ اللَّهَ لاَ يَصْنَعُ بِتَعْذِيبِ هَذَا نَفْسَهُ شَيْئًا ‏"‏ ‏.‏ فَأَمَرَهُ أَنْ يَرْكَبَ ‏.‏\hadithno{3854}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah came to a man who was being supported by two others and said: 'What is the matter with him?' It was said: 'He vowed to walk to the Ka'bah.' He said: 'Allah does not benefit from his torturing himself.' And he told him to ride}}
\hadithdefcmd{nasai}{3855}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَقَالَ إِنْ شَاءَ اللَّهُ فَقَدِ اسْتَثْنَى ‏"‏ ‏.‏\hadithno{3855}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever swears an oath and says: "If Allah wills, then he has made an exception}}
\hadithdefcmd{nasai}{3856}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رَفَعَهُ ‏"‏ قَالَ سُلَيْمَانُ لأَطُوفَنَّ اللَّيْلَةَ عَلَى تِسْعِينَ امْرَأَةً تَلِدُ كُلُّ امْرَأَةٍ مِنْهُنَّ غُلاَمًا يُقَاتِلُ فِي سَبِيلِ اللَّهِ فَقِيلَ لَهُ قُلْ إِنْ شَاءَ اللَّهُ ‏.‏ فَلَمْ يَقُلْ فَطَافَ بِهِنَّ فَلَمْ تَلِدْ مِنْهُنَّ إِلاَّ امْرَأَةٌ وَاحِدَةٌ نِصْفَ إِنْسَانٍ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ قَالَ إِنْ شَاءَ اللَّهُ لَمْ يَحْنَثْ وَكَانَ دَرَكًا لِحَاجَتِهِ ‏"‏ ‏.‏\hadithno{3856}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah, who attributed it to the Prophet:"Sulaiman said: 'I will certainly go around to ninety women tonight, each of whom will bear a child who will fight in the cause of Allah.' It was said to him: 'Say: If Allah wills' but he did not say it. He went around to them but none of them bore a child except for one woman who bore half a person." The Messenger of Allah said: "If he had said: 'If Allah wills,' he would not have broken his vow, and this would have been a means to help him to get what he wanted}}
